﻿param($installPath, $toolsPath, $package, $project)

$analyzersDir = Join-Path (Split-Path -Path $toolsPath -Parent) "analyzers"
if (-Not (Test-Path $analyzersDir))
{
    return
}

$analyzersPaths = Join-Path ( $analyzersDir ) * -Resolve

foreach($analyzersPath in $analyzersPaths)
{
    # Install the language agnostic analyzers.
    if (Test-Path $analyzersPath)
    {
        foreach ($analyzerFilePath in Get-ChildItem $analyzersPath -Filter *.dll)
        {
            if($project.Object.AnalyzerReferences)
            {
                $project.Object.AnalyzerReferences.Add($analyzerFilePath.FullName)
            }
        }
    }
}

# $project.Type gives the language name like (C# or VB.NET)
$languageFolder = ""
if($project.Type -eq "C#")
{
    $languageFolder = "cs"
}
if($project.Type -eq "VB.NET")
{
    $languageFolder = "vb"
}
if($languageFolder -eq "")
{
    return
}

foreach($analyzersPath in $analyzersPaths)
{
    # Install language specific analyzers.
    $languageAnalyzersPath = join-path $analyzersPath $languageFolder
    if (Test-Path $languageAnalyzersPath)
    {
        foreach ($analyzerFilePath in Get-ChildItem $languageAnalyzersPath -Filter *.dll)
        {
            if($project.Object.AnalyzerReferences)
            {
                $project.Object.AnalyzerReferences.Add($analyzerFilePath.FullName)
            }
        }
    }
}
# SIG # Begin signature block
# MIIpGwYJKoZIhvcNAQcCoIIpDDCCKQgCAQExDzANBglghkgBZQMEAgEFADB5Bgor
# BgEEAYI3AgEEoGswaTA0BgorBgEEAYI3AgEeMCYCAwEAAAQQH8w7YFlLCE63JNLG
# KX7zUQIBAAIBAAIBAAIBAAIBADAxMA0GCWCGSAFlAwQCAQUABCCh1voBODYpfCet
# zwmmor0XvG3ngI9/l8E/7NCzPBjyWaCCDeUwggZjMIIES6ADAgECAhMzAAAEQBT8
# C+g+8SRfAAAAAARAMA0GCSqGSIb3DQEBDAUAMH4xCzAJBgNVBAYTAlVTMRMwEQYD
# VQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVNaWNy
# b3NvZnQgQ29ycG9yYXRpb24xKDAmBgNVBAMTH01pY3Jvc29mdCBDb2RlIFNpZ25p
# bmcgUENBIDIwMTEwHhcNMjQxMTE5MTk1MTAwWhcNMjUxMTEyMTk1MTAwWjBjMQsw
# CQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9u
# ZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMQ0wCwYDVQQDEwQuTkVU
# MIIBojANBgkqhkiG9w0BAQEFAAOCAY8AMIIBigKCAYEAwp5dioSFpA9DhkKd9OXW
# VboA9VIKhu8EWRl+qwi+1rSn9FJrDkZ4/lUdCOOz6ozu7C5zpsIx+en67iSssgOx
# cfM1iCDTmAehCqEzsTnv8WJ7FKgFJnPgEcizCrfMGymRbvteQjcyCNWgz8r9ZYOs
# Le//5OMJFjWVA1dEpeksgAyUicnRYndWgTtYDI9giy756T+y6xM/EXad34L8wwDu
# yE4eQWKmTTbZe5Hu5JyfPx7Rgo1Hnio7F+gb/dWtCJTlXWvPQm86ND7Ef3NWfLjS
# KD7Qd+V8MZV23BvjA/D8i6QaKMnUncZuWcsqrxun9zNXb7DlvowaK3nwb/VGLMSz
# DzY+26vhvNfMkIjCUV7rwtrprDl1DazSJNOZYcJfJGhHbKKvKp7fMmrWCCvaXqG+
# 1VamD9C4Vci/b1vzs+fOzhb5SzplZ6MC3L53OcMuCpisqZc/uyYpHfwb7h9IDMae
# qfkVAxvVg8H3+4gztjHJ0RxqO/fEzWGpB3V3WmeCcmCjAgMBAAGjggFzMIIBbzAf
# BgNVHSUEGDAWBgorBgEEAYI3TAgBBggrBgEFBQcDAzAdBgNVHQ4EFgQUj1B9RRfD
# LVcRVwidWUipFGcV2/0wRQYDVR0RBD4wPKQ6MDgxHjAcBgNVBAsTFU1pY3Jvc29m
# dCBDb3Jwb3JhdGlvbjEWMBQGA1UEBRMNNDY0MjIzKzUwMzM4MjAfBgNVHSMEGDAW
# gBRIbmTlUAXTgqoXNzcitW2oynUClTBUBgNVHR8ETTBLMEmgR6BFhkNodHRwOi8v
# d3d3Lm1pY3Jvc29mdC5jb20vcGtpb3BzL2NybC9NaWNDb2RTaWdQQ0EyMDExXzIw
# MTEtMDctMDguY3JsMGEGCCsGAQUFBwEBBFUwUzBRBggrBgEFBQcwAoZFaHR0cDov
# L3d3dy5taWNyb3NvZnQuY29tL3BraW9wcy9jZXJ0cy9NaWNDb2RTaWdQQ0EyMDEx
# XzIwMTEtMDctMDguY3J0MAwGA1UdEwEB/wQCMAAwDQYJKoZIhvcNAQEMBQADggIB
# AJ2WeQqPlxGNTsy9yIduH3+jiBbaLIOPP80imeyasAjU7059y77VR+ddGU0LfRz6
# CDdwQ/A3o22QvkCqpOQRY91/bcCPm1NeP+Ssr0S1hcimFzYVBLgWWq7Kpe6WTW8C
# 5Ds7YbIC1th/WbKOAafAfK3rpfoUCyNqUO/lqGEC38EKUwXasDo49Qy+xVE8kWfh
# NyaBUE3wsvh/PEBn1RIr9fP+DwVPV/v4p5n463qr/9bJtnJXaCk+npWTbEpL059N
# 44uJP1B8f6jmstqtxqdipnmdVWULd3zf6VYakAr68Fw6aQmj9tinxhhEpm+gMtgU
# 2LmXdsP+LzhLmPQd1rc4g1BpasoXlYfdsAmxxV44JkFiY0KuHtKC7/R9ZgWSFMm6
# 3+4RTy4cZP33HgyhboIC/xUbOFPir6AA9dLNdGMWkrGWumaU+A09+6DUsP3qL/lb
# 4UXlsyK99BMstxLh6eoifTYceVDDxn6qqCPGKcexkZdU2eHluAkh7tFGISzc6xZm
# 2SuIwKPnlgxrEwJLynCMXhsHUv2uuDLhJy0wQO6hcJbbN11jYcCZdJOEQQ22bpCi
# lCJWknmOrf6Eeldnsr/dRWBs7iLFVeeR6nevDbF2GymPD9qhj1PxrywKhiXVrr9f
# pseZOv3myCwGMQqpjGmV1FpGYodIIzMS6jIsh0Fku3LeMIIHejCCBWKgAwIBAgIK
# YQ6Q0gAAAAAAAzANBgkqhkiG9w0BAQsFADCBiDELMAkGA1UEBhMCVVMxEzARBgNV
# BAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jv
# c29mdCBDb3Jwb3JhdGlvbjEyMDAGA1UEAxMpTWljcm9zb2Z0IFJvb3QgQ2VydGlm
# aWNhdGUgQXV0aG9yaXR5IDIwMTEwHhcNMTEwNzA4MjA1OTA5WhcNMjYwNzA4MjEw
# OTA5WjB+MQswCQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UE
# BxMHUmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMSgwJgYD
# VQQDEx9NaWNyb3NvZnQgQ29kZSBTaWduaW5nIFBDQSAyMDExMIICIjANBgkqhkiG
# 9w0BAQEFAAOCAg8AMIICCgKCAgEAq/D6chAcLq3YbqqCEE00uvK2WCGfQhsqa+la
# UKq4BjgaBEm6f8MMHt03a8YS2AvwOMKZBrDIOdUBFDFC04kNeWSHfpRgJGyvnkmc
# 6Whe0t+bU7IKLMOv2akrrnoJr9eWWcpgGgXpZnboMlImEi/nqwhQz7NEt13YxC4D
# dato88tt8zpcoRb0RrrgOGSsbmQ1eKagYw8t00CT+OPeBw3VXHmlSSnnDb6gE3e+
# lD3v++MrWhAfTVYoonpy4BI6t0le2O3tQ5GD2Xuye4Yb2T6xjF3oiU+EGvKhL1nk
# kDstrjNYxbc+/jLTswM9sbKvkjh+0p2ALPVOVpEhNSXDOW5kf1O6nA+tGSOEy/S6
# A4aN91/w0FK/jJSHvMAhdCVfGCi2zCcoOCWYOUo2z3yxkq4cI6epZuxhH2rhKEmd
# X4jiJV3TIUs+UsS1Vz8kA/DRelsv1SPjcF0PUUZ3s/gA4bysAoJf28AVs70b1FVL
# 5zmhD+kjSbwYuER8ReTBw3J64HLnJN+/RpnF78IcV9uDjexNSTCnq47f7Fufr/zd
# sGbiwZeBe+3W7UvnSSmnEyimp31ngOaKYnhfsi+E11ecXL93KCjx7W3DKI8sj0A3
# T8HhhUSJxAlMxdSlQy90lfdu+HggWCwTXWCVmj5PM4TasIgX3p5O9JawvEagbJjS
# 4NaIjAsCAwEAAaOCAe0wggHpMBAGCSsGAQQBgjcVAQQDAgEAMB0GA1UdDgQWBBRI
# bmTlUAXTgqoXNzcitW2oynUClTAZBgkrBgEEAYI3FAIEDB4KAFMAdQBiAEMAQTAL
# BgNVHQ8EBAMCAYYwDwYDVR0TAQH/BAUwAwEB/zAfBgNVHSMEGDAWgBRyLToCMZBD
# uRQFTuHqp8cx0SOJNDBaBgNVHR8EUzBRME+gTaBLhklodHRwOi8vY3JsLm1pY3Jv
# c29mdC5jb20vcGtpL2NybC9wcm9kdWN0cy9NaWNSb29DZXJBdXQyMDExXzIwMTFf
# MDNfMjIuY3JsMF4GCCsGAQUFBwEBBFIwUDBOBggrBgEFBQcwAoZCaHR0cDovL3d3
# dy5taWNyb3NvZnQuY29tL3BraS9jZXJ0cy9NaWNSb29DZXJBdXQyMDExXzIwMTFf
# MDNfMjIuY3J0MIGfBgNVHSAEgZcwgZQwgZEGCSsGAQQBgjcuAzCBgzA/BggrBgEF
# BQcCARYzaHR0cDovL3d3dy5taWNyb3NvZnQuY29tL3BraW9wcy9kb2NzL3ByaW1h
# cnljcHMuaHRtMEAGCCsGAQUFBwICMDQeMiAdAEwAZQBnAGEAbABfAHAAbwBsAGkA
# YwB5AF8AcwB0AGEAdABlAG0AZQBuAHQALiAdMA0GCSqGSIb3DQEBCwUAA4ICAQBn
# 8oalmOBUeRou09h0ZyKbC5YR4WOSmUKWfdJ5DJDBZV8uLD74w3LRbYP+vj/oCso7
# v0epo/Np22O/IjWll11lhJB9i0ZQVdgMknzSGksc8zxCi1LQsP1r4z4HLimb5j0b
# pdS1HXeUOeLpZMlEPXh6I/MTfaaQdION9MsmAkYqwooQu6SpBQyb7Wj6aC6VoCo/
# KmtYSWMfCWluWpiW5IP0wI/zRive/DvQvTXvbiWu5a8n7dDd8w6vmSiXmE0OPQvy
# CInWH8MyGOLwxS3OW560STkKxgrCxq2u5bLZ2xWIUUVYODJxJxp/sfQn+N4sOiBp
# mLJZiWhub6e3dMNABQamASooPoI/E01mC8CzTfXhj38cbxV9Rad25UAqZaPDXVJi
# hsMdYzaXht/a8/jyFqGaJ+HNpZfQ7l1jQeNbB5yHPgZ3BtEGsXUfFL5hYbXw3MYb
# BL7fQccOKO7eZS/sl/ahXJbYANahRr1Z85elCUtIEJmAH9AAKcWxm6U/RXceNcbS
# oqKfenoi+kiVH6v7RyOA9Z74v2u3S5fi63V4GuzqN5l5GEv/1rMjaHXmr/r8i+sL
# gOppO6/8MO0ETI7f33VtY5E90Z1WTk+/gFcioXgRMiF670EKsT/7qMykXcGhiJtX
# cVZOSEXAQsmbdlsKgEhr/Xmfwb1tbWrJUnMTDXpQzTGCGowwghqIAgEBMIGVMH4x
# CzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRt
# b25kMR4wHAYDVQQKExVNaWNyb3NvZnQgQ29ycG9yYXRpb24xKDAmBgNVBAMTH01p
# Y3Jvc29mdCBDb2RlIFNpZ25pbmcgUENBIDIwMTECEzMAAARAFPwL6D7xJF8AAAAA
# BEAwDQYJYIZIAWUDBAIBBQCgga4wGQYJKoZIhvcNAQkDMQwGCisGAQQBgjcCAQQw
# HAYKKwYBBAGCNwIBCzEOMAwGCisGAQQBgjcCARUwLwYJKoZIhvcNAQkEMSIEILHG
# 5OyijfDOM5bxiJFmyVasy7d752HLA4qfvHm7QzF9MEIGCisGAQQBgjcCAQwxNDAy
# oBSAEgBNAGkAYwByAG8AcwBvAGYAdKEagBhodHRwOi8vd3d3Lm1pY3Jvc29mdC5j
# b20wDQYJKoZIhvcNAQEBBQAEggGAsa3G9rhyU6zEtGKeaBGc3zbK8Hi1tuDxXktQ
# a6YJnk+oSciNb5hbk3LSnvjsDTK7v0J5gabvzMRLKd2KImdjANHXfVqxwNwAml1Q
# W0a0N3r15Zzy10ouOataQsxl6DyhEIPAZcj/pmNAphYxlxc8fDcEMa9wJchou+dy
# gLiJ5gT2BCcxZgzrlMM0y2bwOyoMHPx7Dyyv7JCrdq0OGh3WZLJJwo7oVnNDUWh1
# FIkjZ7pI/UQdDjHRNp7biS71xg0dDj232tTwmxfAY/rGakcwI0wgoQXYxh9xfYsj
# Lpdwhavh05kEM5GUGHAFNRrTdcbHhpdXTXMD3eAHPKLnpwP9YOSKwSTnY1L0gNeq
# CbzT0SXMm2wneIgSr1LpuIiWTcN4m3lqkED5sKfIJiOY4gzVbcfITSNepqzDs8AW
# lT27DJnRVVTJSPnI8ILtiYAbp8ayC+eAhjhMZJHh30yFuBmy46NG39Hf3Q39xCrI
# BfP9296eREd2DegDYp6nJ9RP5W8xoYIXljCCF5IGCisGAQQBgjcDAwExgheCMIIX
# fgYJKoZIhvcNAQcCoIIXbzCCF2sCAQMxDzANBglghkgBZQMEAgEFADCCAVEGCyqG
# SIb3DQEJEAEEoIIBQASCATwwggE4AgEBBgorBgEEAYRZCgMBMDEwDQYJYIZIAWUD
# BAIBBQAEIJxACsVfpIqL16YKwxBHdM42oHHqYt5OnxHqjGW4n4u+AgZnt6yn4lUY
# EjIwMjUwMjIzMDgyMTMzLjU0WjAEgAIB9KCB0aSBzjCByzELMAkGA1UEBhMCVVMx
# EzARBgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoT
# FU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjElMCMGA1UECxMcTWljcm9zb2Z0IEFtZXJp
# Y2EgT3BlcmF0aW9uczEnMCUGA1UECxMeblNoaWVsZCBUU1MgRVNOOkRDMDAtMDVF
# MC1EOTQ3MSUwIwYDVQQDExxNaWNyb3NvZnQgVGltZS1TdGFtcCBTZXJ2aWNloIIR
# 7TCCByAwggUIoAMCAQICEzMAAAIDux5cADhsdMoAAQAAAgMwDQYJKoZIhvcNAQEL
# BQAwfDELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcT
# B1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEmMCQGA1UE
# AxMdTWljcm9zb2Z0IFRpbWUtU3RhbXAgUENBIDIwMTAwHhcNMjUwMTMwMTk0MjQ2
# WhcNMjYwNDIyMTk0MjQ2WjCByzELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldhc2hp
# bmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jw
# b3JhdGlvbjElMCMGA1UECxMcTWljcm9zb2Z0IEFtZXJpY2EgT3BlcmF0aW9uczEn
# MCUGA1UECxMeblNoaWVsZCBUU1MgRVNOOkRDMDAtMDVFMC1EOTQ3MSUwIwYDVQQD
# ExxNaWNyb3NvZnQgVGltZS1TdGFtcCBTZXJ2aWNlMIICIjANBgkqhkiG9w0BAQEF
# AAOCAg8AMIICCgKCAgEAoZdDB+cAJzsfFIfEbYnRdCdMmhQxyWB06T70Udel9SsR
# g2H0/D63BowiwomjrtytQ5lCFOEXOaJZ3Y2qaTbjoM8FKI+N1W2yceTxU2P2tWfN
# LaalT9DqCiZVJHwz0gSxYF1o+lYGskQiDbS7FGrMtMOYMrA+yCz2bokI2nHuSsQE
# oyn9jFV9anxM2AW0xjRIo0kAisMMnNHmr6+BaN1//rArrgLZE1orLFOuJPKyutI7
# BkQKYhEnX7h69MlgJnO40zjzXhgMeigi9pLaZxnoCw3dSJROgbugUsACBR6+8zsC
# JRaskLgntEkACwmyYbE/cvYsutUSQF7FNLtEwuWGJk0mxCO4NdHWMfFI/r4fSJy6
# CmAuQ6Sm99dW2FXdG8rW85X00bJUUyYKLZ3wgCBjC6hKpPf9lURrvZJSYtY/Z1X6
# smB2KzDzgV3K0GFtI5ijYzi+OwmhAKzc4QwYmtcF3SQDSqjLyfKUHtpvP3Im8gzP
# tQVWarjQKL/TeLSReAArY19I41zQ1DLUmaFRUB/hZFnXz1sdbgSJHPe0fsUS7j41
# MqR2eQNwAC0pHuE2kQb270wWMlth3pzk+52CykzuI8OUKunMN2fc0ykj0Og+Zcom
# KXrOUUdjHTLyUuHwnDyRXmlTr7lhUkPxBrVQUoYZiwfuXsMxc3aX9VLiZrjkE08C
# AwEAAaOCAUkwggFFMB0GA1UdDgQWBBSyKVlAfhHnkNvbFntFXc8VkBiSfTAfBgNV
# HSMEGDAWgBSfpxVdAF5iXYP05dJlpxtTNRnpcjBfBgNVHR8EWDBWMFSgUqBQhk5o
# dHRwOi8vd3d3Lm1pY3Jvc29mdC5jb20vcGtpb3BzL2NybC9NaWNyb3NvZnQlMjBU
# aW1lLVN0YW1wJTIwUENBJTIwMjAxMCgxKS5jcmwwbAYIKwYBBQUHAQEEYDBeMFwG
# CCsGAQUFBzAChlBodHRwOi8vd3d3Lm1pY3Jvc29mdC5jb20vcGtpb3BzL2NlcnRz
# L01pY3Jvc29mdCUyMFRpbWUtU3RhbXAlMjBQQ0ElMjAyMDEwKDEpLmNydDAMBgNV
# HRMBAf8EAjAAMBYGA1UdJQEB/wQMMAoGCCsGAQUFBwMIMA4GA1UdDwEB/wQEAwIH
# gDANBgkqhkiG9w0BAQsFAAOCAgEAkBDG3rA+kwtPEdKGAnUguOdgEKxn/zvPRkOe
# ArYBLG8c8Bg1VHJo1xXJ2iUkzXnQSlV5AYGsEaJz9S4MR+G881Y9nljZsxiMDtRZ
# YZXQDzhwMywRB0aEmeKXXRbWkMaGm1Pzdb1siAojetCLfOYJxeSQ+DDF8neqUvHg
# AyIuk7Y34Cj6LplmtARUP2hM41K3zzda+3KyvqpJi87cPxDUu83pn8seJBkYMGNV
# gXxapv5xZSQz0AYnKnlN3TqfYY+1qg9EXPv+FWesEI3rCMgpL+boVDcti4TQ4tpX
# mLQIiBaZo3zZOBp4C7wtk4/SKzjL9tEq8puSfxYe8lgIj3hrN8gN0GqY2U7X6+zX
# 86QSCUOMU/4nOFhlqoRpUZVQSObujo8N2cUmQi4N70QuCmMqZIfBXSFqCoq44nRB
# pV7DTqPlD/2BuSoXm4rnUwcRnnHyQrrlLKSHUYUrRwELI7/3QKlgS5YaK6tjgmj/
# sBYRN1j4J58eaX5b5bo6HD4LDduPvnXR65dztRRWm1vJtFJAx0igofEE8E5GDsLv
# fYhMQVVpW2GUc9qjiAYy/6MxIbQgdGrioX0yy3rjRgVGgc/qGWfl/VABAqDIZBE4
# 2+mHzWiNU+71QGoroQaFfyQjkE/kWGa4MpMj6c6ZsDDRQQ9b3Vv9vavZ5E1qBIXB
# DjtC/TcwggdxMIIFWaADAgECAhMzAAAAFcXna54Cm0mZAAAAAAAVMA0GCSqGSIb3
# DQEBCwUAMIGIMQswCQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4G
# A1UEBxMHUmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMTIw
# MAYDVQQDEylNaWNyb3NvZnQgUm9vdCBDZXJ0aWZpY2F0ZSBBdXRob3JpdHkgMjAx
# MDAeFw0yMTA5MzAxODIyMjVaFw0zMDA5MzAxODMyMjVaMHwxCzAJBgNVBAYTAlVT
# MRMwEQYDVQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQK
# ExVNaWNyb3NvZnQgQ29ycG9yYXRpb24xJjAkBgNVBAMTHU1pY3Jvc29mdCBUaW1l
# LVN0YW1wIFBDQSAyMDEwMIICIjANBgkqhkiG9w0BAQEFAAOCAg8AMIICCgKCAgEA
# 5OGmTOe0ciELeaLL1yR5vQ7VgtP97pwHB9KpbE51yMo1V/YBf2xK4OK9uT4XYDP/
# XE/HZveVU3Fa4n5KWv64NmeFRiMMtY0Tz3cywBAY6GB9alKDRLemjkZrBxTzxXb1
# hlDcwUTIcVxRMTegCjhuje3XD9gmU3w5YQJ6xKr9cmmvHaus9ja+NSZk2pg7uhp7
# M62AW36MEBydUv626GIl3GoPz130/o5Tz9bshVZN7928jaTjkY+yOSxRnOlwaQ3K
# Ni1wjjHINSi947SHJMPgyY9+tVSP3PoFVZhtaDuaRr3tpK56KTesy+uDRedGbsoy
# 1cCGMFxPLOJiss254o2I5JasAUq7vnGpF1tnYN74kpEeHT39IM9zfUGaRnXNxF80
# 3RKJ1v2lIH1+/NmeRd+2ci/bfV+AutuqfjbsNkz2K26oElHovwUDo9Fzpk03dJQc
# NIIP8BDyt0cY7afomXw/TNuvXsLz1dhzPUNOwTM5TI4CvEJoLhDqhFFG4tG9ahha
# YQFzymeiXtcodgLiMxhy16cg8ML6EgrXY28MyTZki1ugpoMhXV8wdJGUlNi5UPkL
# iWHzNgY1GIRH29wb0f2y1BzFa/ZcUlFdEtsluq9QBXpsxREdcu+N+VLEhReTwDwV
# 2xo3xwgVGD94q0W29R6HXtqPnhZyacaue7e3PmriLq0CAwEAAaOCAd0wggHZMBIG
# CSsGAQQBgjcVAQQFAgMBAAEwIwYJKwYBBAGCNxUCBBYEFCqnUv5kxJq+gpE8RjUp
# zxD/LwTuMB0GA1UdDgQWBBSfpxVdAF5iXYP05dJlpxtTNRnpcjBcBgNVHSAEVTBT
# MFEGDCsGAQQBgjdMg30BATBBMD8GCCsGAQUFBwIBFjNodHRwOi8vd3d3Lm1pY3Jv
# c29mdC5jb20vcGtpb3BzL0RvY3MvUmVwb3NpdG9yeS5odG0wEwYDVR0lBAwwCgYI
# KwYBBQUHAwgwGQYJKwYBBAGCNxQCBAweCgBTAHUAYgBDAEEwCwYDVR0PBAQDAgGG
# MA8GA1UdEwEB/wQFMAMBAf8wHwYDVR0jBBgwFoAU1fZWy4/oolxiaNE9lJBb186a
# GMQwVgYDVR0fBE8wTTBLoEmgR4ZFaHR0cDovL2NybC5taWNyb3NvZnQuY29tL3Br
# aS9jcmwvcHJvZHVjdHMvTWljUm9vQ2VyQXV0XzIwMTAtMDYtMjMuY3JsMFoGCCsG
# AQUFBwEBBE4wTDBKBggrBgEFBQcwAoY+aHR0cDovL3d3dy5taWNyb3NvZnQuY29t
# L3BraS9jZXJ0cy9NaWNSb29DZXJBdXRfMjAxMC0wNi0yMy5jcnQwDQYJKoZIhvcN
# AQELBQADggIBAJ1VffwqreEsH2cBMSRb4Z5yS/ypb+pcFLY+TkdkeLEGk5c9MTO1
# OdfCcTY/2mRsfNB1OW27DzHkwo/7bNGhlBgi7ulmZzpTTd2YurYeeNg2LpypglYA
# A7AFvonoaeC6Ce5732pvvinLbtg/SHUB2RjebYIM9W0jVOR4U3UkV7ndn/OOPcbz
# aN9l9qRWqveVtihVJ9AkvUCgvxm2EhIRXT0n4ECWOKz3+SmJw7wXsFSFQrP8DJ6L
# GYnn8AtqgcKBGUIZUnWKNsIdw2FzLixre24/LAl4FOmRsqlb30mjdAy87JGA0j3m
# Sj5mO0+7hvoyGtmW9I/2kQH2zsZ0/fZMcm8Qq3UwxTSwethQ/gpY3UA8x1RtnWN0
# SCyxTkctwRQEcb9k+SS+c23Kjgm9swFXSVRk2XPXfx5bRAGOWhmRaw2fpCjcZxko
# JLo4S5pu+yFUa2pFEUep8beuyOiJXk+d0tBMdrVXVAmxaQFEfnyhYWxz/gq77EFm
# PWn9y8FBSX5+k77L+DvktxW/tM4+pTFRhLy/AsGConsXHRWJjXD+57XQKBqJC482
# 2rpM+Zv/Cuk0+CQ1ZyvgDbjmjJnW4SLq8CdCPSWU5nR0W2rRnj7tfqAxM328y+l7
# vzhwRNGQ8cirOoo6CGJ/2XBjU02N7oJtpQUQwXEGahC0HVUzWLOhcGbyoYIDUDCC
# AjgCAQEwgfmhgdGkgc4wgcsxCzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpXYXNoaW5n
# dG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVNaWNyb3NvZnQgQ29ycG9y
# YXRpb24xJTAjBgNVBAsTHE1pY3Jvc29mdCBBbWVyaWNhIE9wZXJhdGlvbnMxJzAl
# BgNVBAsTHm5TaGllbGQgVFNTIEVTTjpEQzAwLTA1RTAtRDk0NzElMCMGA1UEAxMc
# TWljcm9zb2Z0IFRpbWUtU3RhbXAgU2VydmljZaIjCgEBMAcGBSsOAwIaAxUAza8U
# V/4s+rLNZQQlxvD9SxcQ9HuggYMwgYCkfjB8MQswCQYDVQQGEwJVUzETMBEGA1UE
# CBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEeMBwGA1UEChMVTWljcm9z
# b2Z0IENvcnBvcmF0aW9uMSYwJAYDVQQDEx1NaWNyb3NvZnQgVGltZS1TdGFtcCBQ
# Q0EgMjAxMDANBgkqhkiG9w0BAQsFAAIFAOtkzhYwIhgPMjAyNTAyMjIyMjI4Mzha
# GA8yMDI1MDIyMzIyMjgzOFowdzA9BgorBgEEAYRZCgQBMS8wLTAKAgUA62TOFgIB
# ADAKAgEAAgIYVQIB/zAHAgEAAgISdjAKAgUA62YflgIBADA2BgorBgEEAYRZCgQC
# MSgwJjAMBgorBgEEAYRZCgMCoAowCAIBAAIDB6EgoQowCAIBAAIDAYagMA0GCSqG
# SIb3DQEBCwUAA4IBAQARpAtYJPBVYfuf25nK/Ek93Ax7o0QsNzmzINZn6xixNTrY
# M/Qdc/7U1QN2MK8tnW7jE4+83EDQyvAWU9jKY6qhROBzsh5GtpjA/5PQ0nR7+lZo
# gPy8ZoKIZ5Vujqp2RpMrLlHRvZ5lyZSOp9O0tX40dE8xFlBvW+k69hTwpClReNTR
# OybVQWmUYLngrWAuMwwBJ9dsqDvemR6/N9+IF6uSKgS+XJ5TPka5+BMnVHtrpZZk
# pqDsYlVHP1exxTq8KKBe7iPTZJDhJge9KNhdkEwuhjGdfkTJ4lAv1evMo7DtZAPI
# E8n6wuxRMfunmt3GuQO0GrmDRtesZG8ni9u8wTxkMYIEDTCCBAkCAQEwgZMwfDEL
# MAkGA1UEBhMCVVMxEzARBgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1v
# bmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEmMCQGA1UEAxMdTWlj
# cm9zb2Z0IFRpbWUtU3RhbXAgUENBIDIwMTACEzMAAAIDux5cADhsdMoAAQAAAgMw
# DQYJYIZIAWUDBAIBBQCgggFKMBoGCSqGSIb3DQEJAzENBgsqhkiG9w0BCRABBDAv
# BgkqhkiG9w0BCQQxIgQgLgY5paCjPeiig3CbVsqziG38QLj4i9Lmue8O6D/ygXMw
# gfoGCyqGSIb3DQEJEAIvMYHqMIHnMIHkMIG9BCBLA90bcZb2k8RTmWZ6UMNA5LD5
# lXbqOUsivYfcPvoTLTCBmDCBgKR+MHwxCzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpX
# YXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVNaWNyb3NvZnQg
# Q29ycG9yYXRpb24xJjAkBgNVBAMTHU1pY3Jvc29mdCBUaW1lLVN0YW1wIFBDQSAy
# MDEwAhMzAAACA7seXAA4bHTKAAEAAAIDMCIEIAD/nGLUwdcn9JpFVEG5f8JWouG5
# od+jsQ90Vmc6xWrCMA0GCSqGSIb3DQEBCwUABIICAJ9T0LZeXS4+JbmWCXMTlJ6G
# 61yTXeF+bkw6zg36NqQgoV5PvKdkH9DvnsiHvxTejH5aGwPtB9P6mi94POTKsWNU
# RzoOdFiC2T+FBk5M6cP3w67ZOxT8Yv+P1OIPd/hCZlxj6/NiISa3aqpuRclDPetr
# iJftq9kuqpn88nRG8dFKW91umC8v9KQYEFyy2ue+r+jsEszJH2Z53NfQfqqRsss9
# 6fVWnFhIuhzydtvcfeQjlgdMyyd/MxW/UhnV5UKwULhAUpb1XbTXNI2CQ1hhlQgj
# qKIHhfGxFJoXoyOrq+/ANIqy/yJYs95uwSdwnepgRmUZMbMPd26hAUnkRRh4z0ip
# 4NRQGQcsdYShZntSf0mJCYF+vq+Xrzf1z0tslNbFDNSzilQlbsCW+5bjU021p7og
# 0gd7I3OPzNUd+PCwsk4vimJzwCKFywavFQaL4wDSULkEsPv5KW1pjd4EAfogamX0
# xrKUpKaRz5RgNxPZjNUyT7OseKcK/aUEM73doEmXtEEIZIhjYg57LtQs9syIsNjb
# EIkZ1Af+BTeXoVLaHolJEx/HV9gIJkk8qZDhKqN7VF8FqK9aRkK/pZnjAtIyfNtP
# GzR5bwOf/U5IuLvmInSVY27t5Li/5vJeKQwOGTAplRXT+4Qkef3Zmffql6CIhXfL
# QnOd1QOBcoZq+MZz43VG
# SIG # End signature block
